==> v3.29.tar.gz: combo/tests/settings.py <==
DATABASES = {
    'default': {
        'ENGINE': os.environ.get('DB_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': 'combo-test-%s' % os.environ.get(
                "BRANCH_NAME", "").replace('/', '-')[:63]
    }
}

LANGUAGE_CODE = 'en-us'

KNOWN_SERVICES = {
    'wcs': {
        'default': {
            'title': 'test', 'url': 'http://127.0.0.1:8999/',
            'secret': 'combo', 'orig': 'combo',
            'backoffice-menu-url': 'http://127.0.0.1:8999/backoffice/',
            'secondary': False},
        'other': {
            'title': 'test2', 'url': 'http://127.0.0.2:8999/',
            'secret': 'combo', 'orig': 'combo',
            'backoffice-menu-url': 'http://127.0.0.2:8999/backoffice/',
            'secondary': True},
    },
    'passerelle': {
        'default': {'title': 'test', 'url': 'http://example.org',
                    'secret': 'combo', 'orig': 'combo',
                    'backoffice-menu-url': 'http://example.org/manage/',}
    },
    'chrono': {
        'default': {
            'title': 'test', 'url': 'http://chrono.example.org',
            'secret': 'combo', 'orig': 'combo',
            'backoffice-menu-url': 'http://chrono.example.org/manage/',
            'secondary': False,
        },
        'other': {
            'title': 'other', 'url': 'http://other.chrono.example.org',
            'secret': 'combo', 'orig': 'combo',
            'backoffice-menu-url': 'http://other.chrono.example.org/manage/',
            'secondary': True,
        }
    }
}

MESSAGE_STORAGE = 'django.contrib.messages.storage.session.SessionStorage'

LINGO_API_SIGN_KEY = '12345'
LINGO_SIGNATURE_KEY = '54321'

COMBO_DASHBOARD_ENABLED = True

import tempfile
MEDIA_ROOT = tempfile.mkdtemp('combo-test')

if 'DISABLE_MIGRATIONS' in os.environ:
    class DisableMigrations(object):
        def __contains__(self, item):
            return True

        def __getitem__(self, item):
            return 'notmigrations'

    MIGRATION_MODULES = DisableMigrations()


FAMILY_SERVICE = {'root': '/'}

BOOKING_CALENDAR_CELL_ENABLED = True
LEGACY_CHART_CELL_ENABLED = True
NEWSLETTERS_CELL_ENABLED = True

USER_PROFILE_CONFIG = {
    'fields': [
        {
            'name': 'first_name',
            'kind': 'string',
            'label': 'First Name',
            'user_visible': True,
        },
        {
            'name': 'birthdate',
            'kind': 'birthdate',
            'label': 'Birth Date',
            'user_visible': True,
        }
    ]
}

==> v3.42.tar.gz: combo/tests/settings.py <==
DATABASES = {
    'default': {
        'ENGINE': os.environ.get('DB_ENGINE', 'django.db.backends.sqlite3'),
        'NAME': 'combo-test-%s' % os.environ.get("BRANCH_NAME", "").replace('/', '-')[:45],
    }
}

LANGUAGE_CODE = 'en-us'

KNOWN_SERVICES = {
    'wcs': {
        'default': {
            'title': 'test',
            'url': 'http://127.0.0.1:8999/',
            'secret': 'combo',
            'orig': 'combo',
            'backoffice-menu-url': 'http://127.0.0.1:8999/backoffice/',
            'secondary': False,
        },
        'other': {
            'title': 'test2',
            'url': 'http://127.0.0.2:8999/',
            'secret': 'combo',
            'orig': 'combo',
            'backoffice-menu-url': 'http://127.0.0.2:8999/backoffice/',
            'secondary': True,
        },
    },
    'passerelle': {
        'default': {
            'title': 'test',
            'url': 'http://example.org',
            'secret': 'combo',
            'orig': 'combo',
            'backoffice-menu-url': 'http://example.org/manage/',
        }
    },
    'chrono': {
        'default': {
            'title': 'test',
            'url': 'http://chrono.example.org',
            'secret': 'combo',
            'orig': 'combo',
            'backoffice-menu-url': 'http://chrono.example.org/manage/',
            'secondary': False,
        },
        'other': {
            'title': 'other',
            'url': 'http://other.chrono.example.org',
            'secret': 'combo',
            'orig': 'combo',
            'backoffice-menu-url': 'http://other.chrono.example.org/manage/',
            'secondary': True,
        },
    },
}

MESSAGE_STORAGE = 'django.contrib.messages.storage.session.SessionStorage'

LINGO_API_SIGN_KEY = '12345'
LINGO_SIGNATURE_KEY = '54321'

COMBO_DASHBOARD_ENABLED = True

import tempfile

MEDIA_ROOT = tempfile.mkdtemp('combo-test')

if 'DISABLE_MIGRATIONS' in os.environ:

    class DisableMigrations(object):
        def __contains__(self, item):
            return True

        def __getitem__(self, item):
            return 'notmigrations'

    MIGRATION_MODULES = DisableMigrations()


FAMILY_SERVICE = {'root': '/'}

BOOKING_CALENDAR_CELL_ENABLED = True
LEGACY_CHART_CELL_ENABLED = True
NEWSLETTERS_CELL_ENABLED = True

USER_PROFILE_CONFIG = {
    'fields': [
        {
            'name': 'first_name',
            'kind': 'string',
            'label': 'First Name',
            'user_visible': True,
        },
        {
            'name': 'birthdate',
            'kind': 'birthdate',
            'label': 'Birth Date',
            'user_visible': True,
        },
    ]
}
